@@ -1,37 +1,38 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "commondefs.h"
 
 #include <cstdlib>
 #include <climits>
 
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QRegExp>
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
+#include <QString>
+#include <QStringList>
+#include <QRegExp>
+#include <QDir>
+#include <QFileInfo>
 
-#include <KDebug>
-#include <KGlobal>
-#include <KStandardDirs>
-#include <KIO/NetAccess>
+#include <QDebug>
+#include <QStandardPaths>
+
+#include <kio/statjob.h>
 
 #ifndef Q_WS_WIN
 #include <unistd.h>
@@ -139,13 +140,13 @@ bool
 System::move(const QString &srcPath, const QString &dstPath)
 {
 	if(!System::copy(srcPath, dstPath)) {
-		kDebug() << "move: error copying" << srcPath << "to" << dstPath;
+		qDebug() << "move: error copying" << srcPath << "to" << dstPath;
 
 		return false;
 	}
 
 	if(!QFile::remove(srcPath)) {
-		kDebug() << "move: error removing" << srcPath;
+		qDebug() << "move: error removing" << srcPath;
 
 		return false;
 	}
@@ -182,13 +183,13 @@ System::homeDir()
 QString
 System::tempDir()
 {
-	QString tempDir = KGlobal::dirs()->saveLocation("tmp");
+	QString tempDir = QStandardPaths::writableLocation(QStandardPaths::TempLocation);
 	tempDir.remove(QRegExp("[\\/]+$"));
 	return tempDir;
 }
 
-KUrl
-System::newUrl(const KUrl &baseUrl, const QString &fileName, const QString &extension, int retries)
+QUrl
+System::newUrl(const QUrl &baseUrl, const QString &fileName, const QString &extension, int retries)
 {
 	if(retries < 0)
 		retries = INT_MAX;
@@ -209,24 +210,26 @@ System::newUrl(const KUrl &baseUrl, const QString &fileName, const QString &exte
 		if(dirInfo.isDir() && dirInfo.isWritable()) {
 			QString newFilePath = newFileDir + newFileName;
 			if(!QFile::exists(newFilePath))
-				return KUrl(newFilePath);
+				return QUrl(newFilePath);
 
 			for(int i = 2, limit = retries + i; i < limit; ++i) {
 				newFilePath = newFileDir + newFileNameBuilder.arg(i);
 				if(!QFile::exists(newFilePath))
-					return KUrl(newFilePath);
+					return QUrl(newFilePath);
 			}
 		}
 	} else {
-		KUrl newUrl = baseUrl;
+		QUrl newUrl = baseUrl;
 
 		newUrl.setPath(newFileDir + newFileName);
-		if(!KIO::NetAccess::exists(newUrl, KIO::NetAccess::DestinationSide, 0))
+		KIO::Job *job = KIO::stat(newUrl, KIO::StatJob::DestinationSide, 2);
+		if(!job->exec())
 			return newUrl;
 
 		for(int i = 2, limit = retries + i; i < limit; ++i) {
 			newUrl.setPath(newFileDir + newFileNameBuilder.arg(i));
-			if(!KIO::NetAccess::exists(newUrl, KIO::NetAccess::DestinationSide, 0))
+			job = KIO::stat(newUrl, KIO::StatJob::DestinationSide, 2);
+			if(!job->exec())
 				return newUrl;
 		}
 	}
@@ -236,12 +239,44 @@ System::newUrl(const KUrl &baseUrl, const QString &fileName, const QString &exte
 
 	QString newFilePath = newFileDir + newFileName;
 	if(!QFile::exists(newFilePath))
-		return KUrl(newFilePath);
+		return QUrl(newFilePath);
 
 	int i = 2;
 	do {
 		newFilePath = newFileDir + newFileNameBuilder.arg(i++);
 	} while(QFile::exists(newFilePath));
 
-	return KUrl(newFilePath);
+	return QUrl(newFilePath);
+}
+
+/*static*/ QUrl
+System::urlFromPath(QString path)
+{
+	QUrl url(path);
+	if(url.isRelative()) {
+		url.setScheme("file");
+		if(path[0] != QDir::separator())
+			url.setPath(QDir::currentPath() + "/" + path);
+	}
+	return url;
+}
+
+
+/*static*/ bool
+System::urlIsInside(const QUrl url, QString path)
+{
+	if(!url.scheme().isEmpty() && url.scheme() != "file")
+		return false;
+	QString urlPath = url.toLocalFile();
+	return urlPath.startsWith(path);
+}
+
+/*static*/ bool
+System::urlIsInside(const QUrl url, QStringList path)
+{
+	for(QStringList::const_iterator i = path.constBegin(), end = path.constEnd(); i != end; i++) {
+		if(urlIsInside(url, *i))
+			return true;
+	}
+	return false;
 }
