@@ -21,8 +21,8 @@
 
 #include "qxtsignalwaiter.h"
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QTimerEvent>
+#include <QCoreApplication>
+#include <QTimerEvent>
 
 QxtSignalWaiter::QxtSignalWaiter(const QObject *sender, const char *signal, unsigned count) :
 	QObject(0),
@@ -148,4 +148,4 @@ QxtSignalWaiter::timerEvent(QTimerEvent *)
 	m_timeout = true;
 }
 
-#include "qxtsignalwaiter.moc"
+
