@@ -26,10 +26,10 @@
 #include <config.h>
 #endif
 
-#include <QtCore/QObject>
-#include <QtCore/QEventLoop>
+#include <QObject>
+#include <QEventLoop>
 
-class QTimerEvent;
+QT_FORWARD_DECLARE_CLASS(QTimerEvent);
 
 // QxtSignalWaiter is, sadly, not reentrant. In particular, only one QxSignalWaiter
 // object can be safely waiting at a time. If a second QxSignalWaiter is used while
