@@ -1,21 +1,22 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "subtitle.h"
 #include "subtitleline.h"
@@ -23,7 +24,7 @@
 #include "subtitleactions.h"
 #include "compositeaction.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace SubtitleComposer;
 
@@ -97,7 +98,8 @@ Subtitle::setPrimaryData(const Subtitle &from, bool usePrimaryData)
 			thisLine->setFormatData(fromIt.current()->formatData());
 			lines.append(thisLine);
 		}
-		processAction(new InsertLinesAction(*this, lines));
+		InsertLinesAction a(*this, lines);
+		processAction(&a);
 	} else if(thisIt.current()) {   // '*this'  had more lines than 'from'
 		for(SubtitleLine *thisLine = thisIt.current(); thisLine; ++thisIt, thisLine = thisIt.current()) {
 			thisLine->setPrimaryText(SString());
@@ -329,6 +331,60 @@ Subtitle::lastLine() const
 	return m_lines.isEmpty() ? 0 : m_lines.last();
 }
 
+bool
+Subtitle::isLineAnchored(int index)
+{
+	if(index < 0 || index >= m_lines.count())
+		return false;
+
+	return isLineAnchored(m_lines[index]);
+}
+
+bool
+Subtitle::isLineAnchored(const SubtitleLine *line)
+{
+	if(!line)
+		return false;
+
+	return m_anchoredLines.indexOf(line) >= 0;
+}
+
+void
+Subtitle::toggleLineAnchor(int index)
+{
+	if(index < 0 || index >= m_lines.count())
+		return;
+
+	toggleLineAnchor(m_lines[index]);
+}
+
+void
+Subtitle::toggleLineAnchor(const SubtitleLine *line)
+{
+	if(!line)
+		return;
+
+	int anchorIndex = m_anchoredLines.indexOf(line);
+
+	if(anchorIndex == -1)
+		m_anchoredLines.append(line);
+	else
+		m_anchoredLines.removeAt(anchorIndex);
+
+	emit lineAnchorChanged(line, anchorIndex == -1);
+}
+
+void
+Subtitle::removeAllAnchors()
+{
+	QList<const SubtitleLine *> anchoredLines = m_anchoredLines;
+
+	m_anchoredLines.clear();
+
+	foreach(auto line, anchoredLines)
+		emit lineAnchorChanged(line, false);
+}
+
 void
 Subtitle::insertLine(SubtitleLine *line, int index)
 {
@@ -548,8 +604,7 @@ Subtitle::splitLines(const RangeList &ranges)
 				}
 
 				line->setTexts(*ptIt, *stIt);
-				line->setDurationTime(Time((long)
-										   (factor * autoDurations[splitLineIndex]) - 1));
+				line->setDurationTime(Time((factor * autoDurations[splitLineIndex]) - 1.0));
 			}
 		}
 	}
@@ -602,6 +657,61 @@ Subtitle::joinLines(const RangeList &ranges)
 	endCompositeAction();
 }
 
+void
+Subtitle::shiftAnchoredLine(SubtitleLine *anchoredLine, const Time &newShowTime)
+{
+	if(m_anchoredLines.indexOf(anchoredLine) == -1 || m_lines.isEmpty())
+		return;
+
+	const SubtitleLine *prevAnchor = NULL;
+	const SubtitleLine *nextAnchor = NULL;
+	foreach(auto anchor, m_anchoredLines) {
+		if((prevAnchor == NULL || prevAnchor->m_showTime < anchor->m_showTime) && anchor->m_showTime < anchoredLine->m_showTime)
+			prevAnchor = anchor;
+		if((nextAnchor == NULL || nextAnchor->m_showTime > anchor->m_showTime) && anchor->m_showTime > anchoredLine->m_showTime)
+			nextAnchor = anchor;
+	}
+	if((prevAnchor && prevAnchor->m_showTime > newShowTime) || (nextAnchor && nextAnchor->m_showTime < newShowTime))
+		return;
+
+	if(!prevAnchor && !nextAnchor) {
+		double shift = newShowTime.toMillis() - anchoredLine->m_showTime.toMillis();
+		foreach(auto line, m_lines)
+			line->shiftTimes(shift);
+	} else {
+		// save times as adjustLines() will modify them, and processing nextAnchor will modify them again
+		Time savedShowTime(anchoredLine->m_showTime);
+		Time savedHideTime(anchoredLine->m_hideTime);
+		if(prevAnchor) {
+			adjustLines(Range(prevAnchor->index(), anchoredLine->index()), prevAnchor->m_showTime.toMillis(), newShowTime.toMillis());
+		} else if(nextAnchor->m_showTime != anchoredLine->m_showTime) {
+			const SubtitleLine *first = firstLine();
+			double scaleFactor = (nextAnchor->m_showTime.toMillis() - newShowTime.toMillis()) / (nextAnchor->m_showTime.toMillis() - anchoredLine->m_showTime.toMillis());
+			Time firstShowTime(scaleFactor * (first->m_showTime.toMillis() - nextAnchor->m_showTime.toMillis()) + nextAnchor->m_showTime.toMillis());
+			adjustLines(Range(first->index(), anchoredLine->index()), firstShowTime.toMillis(), newShowTime.toMillis());
+		}
+
+		double lastShowTime;
+		const SubtitleLine *last;
+		if(nextAnchor) {
+			last = nextAnchor;
+			lastShowTime = nextAnchor->m_showTime.toMillis();
+		} else if(anchoredLine->m_showTime != prevAnchor->m_showTime) {
+			last = lastLine();
+			double scaleFactor = (newShowTime.toMillis() - prevAnchor->m_showTime.toMillis()) / (savedShowTime.toMillis() - prevAnchor->m_showTime.toMillis());
+			lastShowTime = scaleFactor * (last->m_showTime.toMillis() - prevAnchor->m_showTime.toMillis()) + prevAnchor->m_showTime.toMillis();
+		} else {
+			last = NULL;
+			lastShowTime = 0;
+		}
+		if(newShowTime.toMillis() < lastShowTime) {
+			anchoredLine->m_showTime = savedShowTime;
+			anchoredLine->m_hideTime = savedHideTime;
+			adjustLines(Range(anchoredLine->index(), last->index()), newShowTime.toMillis(), lastShowTime);
+		}
+	}
+}
+
 void
 Subtitle::shiftLines(const RangeList &ranges, long msecs)
 {
@@ -610,8 +720,18 @@ Subtitle::shiftLines(const RangeList &ranges, long msecs)
 
 	beginCompositeAction(i18n("Shift Lines"));
 
-	for(SubtitleIterator it(*this, ranges); it.current(); ++it)
-		it.current()->shiftTimes(msecs);
+	if(!m_anchoredLines.empty()) {
+		for(SubtitleIterator it(*this, ranges); it.current(); ++it) {
+			SubtitleLine *line = it.current();
+			if(m_anchoredLines.indexOf(line) != -1) {
+				shiftAnchoredLine(line, line->showTime().shifted(msecs));
+				break;
+			}
+		}
+	} else {
+		for(SubtitleIterator it(*this, ranges); it.current(); ++it)
+			it.current()->shiftTimes(msecs);
+	}
 
 	endCompositeAction();
 }
@@ -628,11 +748,11 @@ Subtitle::adjustLines(const Range &range, long newFirstTime, long newLastTime)
 	if(firstIndex >= lastIndex)
 		return;
 
-	long oldFirstTime = m_lines.at(firstIndex)->showTime().toMillis();
-	long oldLastTime = m_lines.at(lastIndex)->showTime().toMillis();
-	long oldDeltaTime = oldLastTime - oldFirstTime;
+	double oldFirstTime = m_lines.at(firstIndex)->showTime().toMillis();
+	double oldLastTime = m_lines.at(lastIndex)->showTime().toMillis();
+	double oldDeltaTime = oldLastTime - oldFirstTime;
 
-	long newDeltaTime = newLastTime - newFirstTime;
+	double newDeltaTime = newLastTime - newFirstTime;
 
 	// special case in which we can't procede as there's no way to
 	// linearly transform the same time into two different ones...
@@ -643,8 +763,8 @@ Subtitle::adjustLines(const Range &range, long newFirstTime, long newLastTime)
 	double scaleFactor;
 
 	if(oldDeltaTime) {
-		shiftMseconds = newFirstTime - ((double)newDeltaTime / oldDeltaTime) * oldFirstTime;
-		scaleFactor = (double)newDeltaTime / oldDeltaTime;
+		shiftMseconds = newFirstTime - (newDeltaTime / oldDeltaTime) * oldFirstTime;
+		scaleFactor = newDeltaTime / oldDeltaTime;
 	} else {                                        // oldDeltaTime == 0 && newDeltaTime == 0
 		// in this particular case we can make the adjust transformation act as a plain shift
 		shiftMseconds = newFirstTime - oldFirstTime;
@@ -688,7 +808,7 @@ Subtitle::sortLines(const Range &range)
 				}
 			}
 
-//                      kDebug() << "moving from" << fromIndex << "to" << toIndex;
+//                      qDebug() << "moving from" << fromIndex << "to" << toIndex;
 			processAction(new MoveLineAction(*this, fromIndex, toIndex));
 
 			// moving the lines invalidates the iterator so we recreate it and advance it to where it was
@@ -1133,7 +1253,7 @@ Subtitle::setStyleFlags(const RangeList &ranges, int styleFlags)
 	beginCompositeAction(i18n("Set Lines Style"));
 
 	for(SubtitleIterator it(*this, ranges); it.current(); ++it) {
-		kDebug() << it.current()->primaryText().string();
+		qDebug() << it.current()->primaryText().string();
 
 		it.current()->setPrimaryText(SString(it.current()->primaryText()).setStyleFlags(0, -1, styleFlags));
 		it.current()->setSecondaryText(SString(it.current()->secondaryText()).setStyleFlags(0, -1, styleFlags));
@@ -1221,7 +1341,7 @@ Subtitle::clearErrors(const RangeList &ranges, int errorFlags)
 }
 
 void
-Subtitle::checkErrors(const RangeList &ranges, int errorFlags, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines)
+Subtitle::checqCriticals(const RangeList &ranges, int errorFlags, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines)
 {
 	beginCompositeAction(i18n("Check Lines Errors"));
 
@@ -1233,7 +1353,7 @@ Subtitle::checkErrors(const RangeList &ranges, int errorFlags, int minDurationMs
 }
 
 void
-Subtitle::recheckErrors(const RangeList &ranges, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines)
+Subtitle::rechecqCriticals(const RangeList &ranges, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines)
 {
 	beginCompositeAction(i18n("Check Lines Errors"));
 
@@ -1377,16 +1497,16 @@ Subtitle::setLastValidCachedIndex(int lastValidCachedIndex)
 	m_lastValidCachedIndex = lastValidCachedIndex;
 
 	/*
-	   kDebug() << "last valid cached index" << m_lastValidCachedIndex;
+	   qDebug() << "last valid cached index" << m_lastValidCachedIndex;
 
 	   QStringList cacheIndexList, indexList;
 	   for ( int lineIndex = 0, linesCount = m_lines.count(); lineIndex < linesCount; ++lineIndex )
 	   cacheIndexList << QString::number( m_lines.at( lineIndex )->m_cachedIndex );
-	   kDebug() << "cached indexes:" << cacheIndexList.join( " " );
+	   qDebug() << "cached indexes:" << cacheIndexList.join( " " );
 
 	   for ( int lineIndex = 0, linesCount = m_lines.count(); lineIndex < linesCount; ++lineIndex )
 	   indexList << QString::number( m_lines.at( lineIndex )->index() );
-	   kDebug() << "indexes:" << indexList.join( " " );
+	   qDebug() << "indexes:" << indexList.join( " " );
 	 */
 }
 
@@ -1403,4 +1523,4 @@ SubtitleCompositeActionExecutor::~SubtitleCompositeActionExecutor()
 	m_subtitle.endCompositeAction();
 }
 
-#include "subtitle.moc"
+
