@@ -32,10 +32,10 @@
 #include "actionmanager.h"
 #include "formatdata.h"
 
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QList>
+#include <QObject>
+#include <QString>
+#include <QStringList>
+#include <QList>
 
 namespace SubtitleComposer {
 class CompositeAction;
@@ -114,6 +114,16 @@ public:
 	SubtitleLine * lastLine();
 	const SubtitleLine * lastLine() const;
 
+	inline const QList<SubtitleLine *> & allLines() const { return m_lines; }
+
+	inline const QList<const SubtitleLine *> & anchoredLines() const { return m_anchoredLines; }
+
+	bool isLineAnchored(int index);
+	bool isLineAnchored(const SubtitleLine *line);
+	void toggleLineAnchor(int index);
+	void toggleLineAnchor(const SubtitleLine *line);
+	void removeAllAnchors();
+
 	void insertLine(SubtitleLine *line, int index = -1);
 	void insertLines(const QList<SubtitleLine *> &lines, int index = -1);
 	SubtitleLine * insertNewLine(int index, bool timeAfter, TextTarget target);
@@ -124,6 +134,8 @@ public:
 	void splitLines(const RangeList &ranges);
 	void joinLines(const RangeList &ranges);
 
+	void shiftAnchoredLine(SubtitleLine *anchoredLine, const Time &newShowTime);
+
 	void shiftLines(const RangeList &ranges, long msecs);
 	void adjustLines(const Range &range, long firstTime, long lastTime);
 	void sortLines(const Range &range);
@@ -158,8 +170,8 @@ public:
 	void toggleMarked(const RangeList &ranges);
 
 	void clearErrors(const RangeList &ranges, int errorFlags);
-	void checkErrors(const RangeList &ranges, int errorFlags, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines);
-	void recheckErrors(const RangeList &ranges, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines);
+	void checqCriticals(const RangeList &ranges, int errorFlags, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines);
+	void rechecqCriticals(const RangeList &ranges, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines);
 
 signals:
 	void primaryDirtyStateChanged(bool dirty);
@@ -171,6 +183,8 @@ signals:
 	void linesAboutToBeRemoved(int firstIndex, int lastIndex);
 	void linesRemoved(int firstIndex, int lastIndex);
 
+	void lineAnchorChanged(const SubtitleLine *line, bool anchored);
+
 /// forwarded line signals
 	void linePrimaryTextChanged(SubtitleLine *line, const SString &text);
 	void lineSecondaryTextChanged(SubtitleLine *line, const SString &text);
@@ -206,6 +220,7 @@ private:
 
 	double m_framesPerSecond;
 	mutable QList<SubtitleLine *> m_lines;
+	QList<const SubtitleLine *> m_anchoredLines;
 
 	int m_lastValidCachedIndex;             // all SubtitleLines with a m_cachedIndex greater
 // than this value have to recalculate its value
