@@ -1,29 +1,30 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "subtitleline.h"
 #include "subtitlelineactions.h"
 #include "subtitle.h"
 
-#include <QtCore/QRegExp>
+#include <QRegExp>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <math.h>
 
@@ -241,9 +242,9 @@ SubtitleLine::index() const
 				break;
 			}
 		}
-//		kDebug() << "searched index";
+//		qDebug() << "searched index";
 	}
-//	kDebug() << "index" << m_index << "| text" << m_primaryText.string();
+//	qDebug() << "index" << m_index << "| text" << m_primaryText.string();
 	return m_cachedIndex;
 }
 
@@ -501,8 +502,16 @@ SubtitleLine::showTime() const
 void
 SubtitleLine::setShowTime(const Time &showTime)
 {
-	if(m_showTime != showTime)
+	if(m_showTime == showTime)
+		return;
+
+	if(m_subtitle && m_subtitle->isLineAnchored(this)) {
+		m_subtitle->beginCompositeAction(i18n("Set Line Show Time"));
+		m_subtitle->shiftAnchoredLine(this, showTime);
+		m_subtitle->endCompositeAction();
+	} else {
 		processAction(new SetLineShowTimeAction(*this, showTime));
+	}
 }
 
 Time
@@ -530,6 +539,21 @@ SubtitleLine::setDurationTime(const Time &durationTime)
 	setHideTime(m_showTime + durationTime);
 }
 
+void
+SubtitleLine::setTimes(const Time &showTime, const Time &hideTime)
+{
+	if(m_showTime == showTime && m_hideTime == hideTime)
+		return;
+
+	if(m_subtitle && m_subtitle->isLineAnchored(this)) {
+		m_subtitle->beginCompositeAction(i18n("Set Line Times"));
+		m_subtitle->shiftAnchoredLine(this, showTime);
+		m_subtitle->endCompositeAction();
+	} else {
+		processAction(new SetLineTimesAction(*this, showTime, hideTime, i18n("Set Line Times")));
+	}
+}
+
 int
 SubtitleLine::primaryCharacters() const
 {
@@ -605,30 +629,20 @@ SubtitleLine::autoDuration(int msecsPerChar, int msecsPerWord, int msecsPerLine,
 	}
 }
 
-void
-SubtitleLine::setTimes(const Time &showTime, const Time &hideTime)
-{
-	if(m_showTime != showTime || m_hideTime != hideTime)
-		processAction(new SetLineTimesAction(*this, showTime, hideTime, i18n("Set Line Times")));
-}
-
 void
 SubtitleLine::shiftTimes(long mseconds)
 {
-	if(mseconds)
-		processAction(new SetLineTimesAction(*this, Time(m_showTime.toMillis() + mseconds), Time(m_hideTime.toMillis() + mseconds), i18n("Shift Line Times")
-											 )
-					  );
+	if(!mseconds)
+		return;
+
+	processAction(new SetLineTimesAction(*this, m_showTime.shifted(mseconds), m_hideTime.shifted(mseconds), i18n("Shift Line Times")));
 }
 
 void
 SubtitleLine::adjustTimes(double shiftMseconds, double scaleFactor)
 {
-	if(shiftMseconds || scaleFactor != 1.0) {
-		processAction(new SetLineTimesAction(*this, m_showTime.adjusted(shiftMseconds, scaleFactor), m_hideTime.adjusted(shiftMseconds, scaleFactor), i18n("Adjust Line Times")
-											 )
-					  );
-	}
+	if(shiftMseconds || scaleFactor != 1.0)
+		processAction(new SetLineTimesAction(*this, m_showTime.adjusted(shiftMseconds, scaleFactor), m_hideTime.adjusted(shiftMseconds, scaleFactor), i18n("Adjust Line Times")));
 }
 
 /// ERRORS
@@ -1033,4 +1047,4 @@ SubtitleLine::processAction(Action *action)
 	}
 }
 
-#include "subtitleline.moc"
+
