@@ -98,6 +98,7 @@
 #define ACT_TOGGLE_MUTED "toggle_muted"
 #define ACT_INCREASE_VOLUME "increase_volume"
 #define ACT_DECREASE_VOLUME "decrease_volume"
+#define ACT_DEMUX_TEXT_STREAM "demux_text_stream"
 #define ACT_SET_ACTIVE_AUDIO_STREAM "set_active_audio_stream"
 #define ACT_INCREASE_SUBTITLE_FONT "increase_font_size"
 #define ACT_DECREASE_SUBTITLE_FONT "decrease_font_size"
@@ -105,16 +106,12 @@
 #define ACT_SHIFT_TO_VIDEO_POSITION "shift_to_video_position"
 #define ACT_ADJUST_TO_VIDEO_POSITION_A_F "adjust_to_video_position_anchor_first"
 #define ACT_ADJUST_TO_VIDEO_POSITION_A_L "adjust_to_video_position_anchor_last"
-#define ACT_EXTRACT_VIDEO_AUDIO "extract_video_audio"
-#define ACT_CANCEL_AUDIO_EXTRACTION "cancel_audio_extraction"
-#define ACT_OPEN_WAVEFORM "open_audiolevels"
-#define ACT_RECENT_WAVEFORMS "recent_audiolevels"
-#define ACT_SAVE_LEVELS_AS "save_audiolevels_as"
-#define ACT_CLOSE_WAVEFORM "close_audiolevels"
-#define ACT_INCREASE_LEVELS_V_ZOOM "increase_audiolevels_v_zoom"
-#define ACT_DECREASE_LEVELS_V_ZOOM "decrease_audiolevels_v_zoom"
-#define ACT_INCREASE_LEVELS_H_ZOOM "increase_audiolevels_h_zoom"
-#define ACT_DECREASE_LEVELS_H_ZOOM "decrease_audiolevels_h_zoom"
+#define ACT_ANCHOR_TOGGLE "anchor_toggle"
+#define ACT_ANCHOR_REMOVE_ALL "anchor_remove_all"
 #define ACT_SCRIPTS_MANAGER "scripts_manager"
+#define ACT_WAVEFORM_ZOOM_IN "waveform-zoom-in"
+#define ACT_WAVEFORM_ZOOM_OUT "waveform-zoom-out"
+#define ACT_WAVEFORM_AUTOSCROLL "waveform-autoscroll"
+#define ACT_ASR_IMPORT_AUDIO_STREAM "asr_import_audio_stream"
 
 #endif
