@@ -1,56 +1,54 @@
 #ifndef APPLICATION_H
 #define APPLICATION_H
 
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include "mainwindow.h"
-#include "configs/generalconfig.h"
-#include "configs/spellingconfig.h"
-#include "configs/errorsconfig.h"
-#include "configs/playerconfig.h"
 #include "../core/subtitle.h"
-#include "../config/appconfig.h"
 #include "../formats/format.h"
+#include "scconfig.h"
 
-#include <QtCore/QMap>
-#include <QtCore/QString>
-#include <QtGui/QKeySequence>
+#include <QMap>
+#include <QString>
+#include <QKeySequence>
 
-#include <KApplication>
-#include <KAction>
-#include <KUrl>
-#include <kencodingdetector.h>
+#include <QApplication>
+#include <QAction>
+#include <QUrl>
+#include <sonnet/configwidget.h>
 
+QT_FORWARD_DECLARE_CLASS(QAction)
 class KComboBox;
-class KAction;
 class KToggleAction;
 class KRecentFilesActionExt;
 class KCodecActionExt;
 
 namespace SubtitleComposer {
-class Player;
-class Decoder;
+class VideoPlayer;
+class TextDemux;
+class SpeechProcessor;
 
 class PlayerWidget;
 class LinesWidget;
@@ -69,14 +67,16 @@ class ErrorTracker;
 
 class ScriptsManager;
 
-class Application : public KApplication
+class Application : public QApplication
 {
 	Q_OBJECT
 
 public:
-	Application();
+	Application(int &argc, char **argv);
 	virtual ~Application();
 
+	void init();
+
 	static Application * instance();
 
 	Subtitle * subtitle() const;
@@ -90,11 +90,6 @@ public:
 	void loadConfig();
 	void saveConfig();
 
-	GeneralConfig * generalConfig() { return static_cast<GeneralConfig *>(m_config.group("General")); }
-	SpellingConfig * spellingConfig() { return static_cast<SpellingConfig *>(m_config.group("Spelling")); }
-	ErrorsConfig * errorsConfig() { return static_cast<ErrorsConfig *>(m_config.group("Errors")); }
-	PlayerConfig * playerConfig() { return static_cast<PlayerConfig *>(m_config.group("Player")); }
-
 	QAction * action(const char *actionName);
 
 	/**
@@ -106,7 +101,7 @@ public:
 
 	const QStringList & availableEncodingNames() const;
 
-	const KUrl & lastSubtitleDirectory() const;
+	const QUrl & lastSubtitleDirectory() const;
 
 public slots:
 	void undo();
@@ -115,20 +110,23 @@ public slots:
 	void newSubtitle();
 	void openSubtitle();
 	void reopenSubtitleWithCodec(QTextCodec *codec);
-	void reopenSubtitleWithDetectScript(KEncodingDetector::AutoDetectScript autodetectScript);
-	void reopenSubtitleWithCodecOrDetectScript(QTextCodec *codec, KEncodingDetector::AutoDetectScript autodetectScript);
-	void openSubtitle(const KUrl &url, bool warnClashingUrls = true);
+	void reopenSubtitleWithDetectScript();
+	void reopenSubtitleWithCodecOrDetectScript(QTextCodec *codec);
+	void demuxTextStream(int textStreamIndex);
+	void openSubtitle(const QUrl &url, bool warnClashingUrls = true);
 	bool saveSubtitle();
 	bool saveSubtitleAs();
 	bool closeSubtitle();
 
+	void speechImportAudioStream(int audioStreamIndex);
+
 	void newSubtitleTr();
 	void openSubtitleTr();
 	void reopenSubtitleTrWithCodec(QTextCodec *codec);
-	void reopenSubtitleTrWithDetectScript(KEncodingDetector::AutoDetectScript autodetectScript);
-	void reopenSubtitleTrWithCodecOrDetectScript(QTextCodec *codec, KEncodingDetector::AutoDetectScript autodetectScript);
+	void reopenSubtitleTrWithDetectScript();
+	void reopenSubtitleTrWithCodecOrDetectScript(QTextCodec *codec);
 
-	void openSubtitleTr(const KUrl &url, bool warnClashingUrls = true);
+	void openSubtitleTr(const QUrl &url, bool warnClashingUrls = true);
 	bool saveSubtitleTr();
 	bool saveSubtitleTrAs();
 	bool closeSubtitleTr();
@@ -160,7 +158,7 @@ public slots:
 	void retrocedeCurrentLine();
 	void advanceCurrentLine();
 
-	void checkErrors();
+	void checqCriticals();
 	void recheckAllErrors();
 	void recheckSelectedErrors();
 	void clearErrors();
@@ -168,7 +166,6 @@ public slots:
 	void clearSelectedMarks();
 
 	void showErrors();
-	void showErrorsConfig();
 
 	void toggleSelectedLinesMark();
 	void toggleSelectedLinesBold();
@@ -199,7 +196,7 @@ public slots:
 	void translate();
 
 	void openVideo();
-	void openVideo(const KUrl &url);
+	void openVideo(const QUrl &url);
 
 	void toggleFullScreenMode();
 	void setFullScreenMode(bool enabled);
@@ -212,22 +209,13 @@ public slots:
 	void setCurrentLineShowTimeFromVideo();
 	void setCurrentLineHideTimeFromVideo();
 
+	void anchorToggle();
+	void anchorRemoveAll();
+
 	void shiftToVideoPosition();
 	void adjustToVideoPositionAnchorLast();
 	void adjustToVideoPositionAnchorFirst();
 
-	void extractVideoAudio();
-
-	void openAudioLevels();
-	void openAudioLevels(const KUrl &url);
-	void saveAudioLevelsAs();
-	void closeAudioLevels();
-
-	void increaseAudioLevelsVZoom();
-	void decreaseAudioLevelsVZoom();
-	void increaseAudioLevelsHZoom();
-	void decreaseAudioLevelsHZoom();
-
 signals:
 	void subtitleOpened(Subtitle *subtitle);
 	void subtitleClosed();
@@ -236,26 +224,29 @@ signals:
 	void fullScreenModeChanged(bool value);
 
 private:
-	QTextCodec * codecForUrl(const KUrl &url, bool useRecentFiles, bool useDefault);
+	QTextCodec * codecForUrl(const QUrl &url, bool useRecentFiles, bool useDefault);
 	QTextCodec * codecForEncoding(const QString &encoding, bool useDefault);
 
-	bool acceptClashingUrls(const KUrl &subtitleUrl, const KUrl &subtitleTrUrl);
+	bool acceptClashingUrls(const QUrl &subtitleUrl, const QUrl &subtitleTrUrl);
 
-	KUrl saveSplitSubtitle(const Subtitle &subtitle, const KUrl &srcUrl, QString encoding, QString format, bool primary);
+	QUrl saveSplitSubtitle(const Subtitle &subtitle, const QUrl &srcUrl, QString encoding, QString format, bool primary);
 
 	void setupActions();
 
 	Time videoPosition(bool compensate = false);
 
 	static const QString & buildMediaFilesFilter();
-	static const QString & buildLevelsFilesFilter();
 
 	bool applyTranslation(RangeList ranges, bool primary, int inputLanguage, int outputLanguage, int textTargets);
 
+	void updateActionTexts();
+
 private slots:
 	void updateTitle();
 	void updateUndoRedoToolTips();
 
+	void onWaveformDoubleClicked(Time time);
+
 	void onLineDoubleClicked(SubtitleLine *line);
 	void onHighlightLine(SubtitleLine *line, bool primary = true, int firstIndex = -1, int lastIndex = -1);
 	void onPlayingLineChanged(SubtitleLine *line);
@@ -265,40 +256,36 @@ private slots:
 	void onPlayerPlaying();
 	void onPlayerPaused();
 	void onPlayerStopped();
+	void onPlayerTextStreamsChanged(const QStringList &textStreams);
 	void onPlayerAudioStreamsChanged(const QStringList &audioStreams);
 	void onPlayerActiveAudioStreamChanged(int audioStream);
 	void onPlayerMuteChanged(bool muted);
-	void onPlayerOptionChanged(const QString &option, const QString &value);
 
-	void onDecodingError(const QString &errorMessage);
-
-	void onGeneralOptionChanged(const QString &option, const QString &value);
+	void onConfigChanged();
 
 	void setActiveSubtitleStream(int subtitleStream);
 
-	void updateConfigFromDialog();
+	void showPreferences();
 
 private:
-	void toggleFullScreen(bool on);
-
-	AppConfig m_config;
-
 	Subtitle *m_subtitle;
-	KUrl m_subtitleUrl;
+	QUrl m_subtitleUrl;
 	QString m_subtitleFileName;
 	QString m_subtitleEncoding;
 	Format::NewLine m_subtitleEOL;
 	QString m_subtitleFormat;
 
 	bool m_translationMode;
-	KUrl m_subtitleTrUrl;
+	QUrl m_subtitleTrUrl;
 	QString m_subtitleTrFileName;
 	QString m_subtitleTrEncoding;
 	Format::NewLine m_subtitleTrEOL;
 	QString m_subtitleTrFormat;
 
-	Player *m_player;
-	Decoder *m_decoder;
+	VideoPlayer *m_player;
+
+	TextDemux *m_textDemux;
+	SpeechProcessor *m_speechProcessor;
 
 	SubtitleLine *m_lastFoundLine;
 
@@ -306,14 +293,8 @@ private:
 	PlayerWidget *m_playerWidget;
 	LinesWidget *m_linesWidget;
 	CurrentLineWidget *m_curLineWidget;
-	StatusBar2 *m_statusBar;
 
-	ConfigDialog *m_configDialog;
-	ErrorsDialog *m_errorsDialog;
-
-	ErrorsWidget *m_errorsWidget;
-
-	KUrl m_lastSubtitleUrl;
+	QUrl m_lastSubtitleUrl;
 	KRecentFilesActionExt *m_recentSubtitlesAction;
 	KRecentFilesActionExt *m_recentSubtitlesTrAction;
 
@@ -329,12 +310,9 @@ private:
 
 	ScriptsManager *m_scriptsManager;
 
-	KUrl m_lastVideoUrl;
+	QUrl m_lastVideoUrl;
 	bool m_linkCurrentLineToPosition;
 	KRecentFilesActionExt *m_recentVideosAction;
-
-	KUrl m_lastAudioLevelsUrl;
-	KRecentFilesActionExt *m_recentAudioLevelsAction;
 };
 
 Application * app();
