@@ -1,36 +1,36 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "translator.h"
 #include "../../common/qxtsignalwaiter.h"
 
-#include <QtCore/QRegExp>
-#include <QtCore/QTextCodec>
-#include <QtGui/QLabel>
-#include <QtGui/QProgressBar>
-#include <QtGui/QBoxLayout>
+#include <QRegExp>
+#include <QTextCodec>
+#include <QLabel>
+#include <QProgressBar>
+#include <QBoxLayout>
+#include <QUrlQuery>
+#include <QDebug>
 
-#include <KDebug>
-#include <KLocale>
-#include <KDialog>
+#include <KLocalizedString>
 
-#include <kjob.h>
 #include <KIO/Job>
 
 using namespace SubtitleComposer;
@@ -182,13 +182,10 @@ Translator::abort()
 QByteArray
 Translator::prepareUrlEncodedData(const QMap<QString, QString> &params)
 {
-	QByteArray data;
-
-	QUrl url;
+	QUrlQuery query;
 	for(QMap<QString, QString>::ConstIterator it = params.begin(), end = params.end(); it != end; ++it)
-		url.addQueryItem(it.key(), it.value());
-
-	return url.toEncoded(QUrl::RemoveScheme | QUrl::RemoveAuthority | QUrl::RemovePath).remove(0, 1);
+		query.addQueryItem(it.key(), it.value());
+	return query.toString().toUtf8();
 }
 
 // "Content-type" => "multipart/form-data; boundary=" MULTIPART_DATA_BOUNDARY
@@ -227,7 +224,7 @@ Translator::startChunkDownload(int chunkNumber)
 	// QByteArray postData = prepareMultipartData( params );
 	QByteArray postData = prepareUrlEncodedData(params);
 
-	m_currentTransferJob = KIO::http_post(KUrl("http://translate.google.com/translate_t"), postData, KIO::HideProgressInfo);
+	m_currentTransferJob = KIO::http_post(QUrl("http://translate.google.com/translate_t"), postData, KIO::HideProgressInfo);
 
 //  m_currentTransferJob->addMetaData( "content-type", "Content-Type: multipart/form-data; boundary=" MULTIPART_DATA_BOUNDARY );
 	m_currentTransferJob->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
@@ -264,7 +261,7 @@ Translator::onTransferJobResult(KJob *job)
 	if(job->error()) {
 		m_aborted = false;
 		m_errorMessage = job->errorString();
-		kDebug() << m_errorMessage;
+		qDebug() << m_errorMessage;
 		emit finishedWithError(m_errorMessage);
 		return;
 	}
@@ -603,4 +600,4 @@ Translator::namedEntities()
 	return entities;
 }
 
-#include "translator.moc"
+
